@@ -1,7 +1,7 @@
 /*
     Implementation of GPTData class derivative with popt-based command
     line processing
-    Copyright (C) 2010-2014 Roderick W. Smith
+    Copyright (C) 2010-2024 Roderick W. Smith
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,10 +26,13 @@
 #include <popt.h>
 #include "gptcl.h"
 
+using namespace std;
+
 GPTDataCL::GPTDataCL(void) {
    attributeOperation = backupFile = partName = hybrids = newPartInfo = NULL;
    mbrParts = twoParts = outDevice = typeCode = partGUID = diskGUID = NULL;
    alignment = DEFAULT_ALIGNMENT;
+   alignEnd = false;
    deletePartNum = infoPartNum = largestPartNum = bsdPartNum = 0;
    tableSize = GPT_SIZE;
 } // GPTDataCL constructor
@@ -64,7 +67,8 @@ int GPTDataCL::DoOptions(int argc, char* argv[]) {
    GPTData secondDevice;
    int opt, numOptions = 0, saveData = 0, neverSaveData = 0;
    int partNum = 0, newPartNum = -1, saveNonGPT = 1, retval = 0, pretend = 0;
-   uint64_t low, high, startSector, endSector, sSize, mainTableLBA;
+   int byteSwapPartNum = 0;
+   uint64_t low, high, startSector, endSector, sSize, mainTableLBA, secondTableLBA;
    uint64_t temp; // temporary variable; free to use in any case
    char *device;
    string cmd, typeGUID, name;
@@ -76,19 +80,22 @@ int GPTDataCL::DoOptions(int argc, char* argv[]) {
           "list|[partnum:show|or|nand|xor|=|set|clear|toggle|get[:bitnum|hexbitmask]]"},
       {"set-alignment", 'a', POPT_ARG_INT, &alignment, 'a', "set sector alignment", "value"},
       {"backup", 'b', POPT_ARG_STRING, &backupFile, 'b', "backup GPT to file", "file"},
+      {"byte-swap-name", 'B',  POPT_ARG_INT, &byteSwapPartNum, 'B', "byte-swap partition's name", "partnum"},
       {"change-name", 'c', POPT_ARG_STRING, &partName, 'c', "change partition's name", "partnum:name"},
       {"recompute-chs", 'C', POPT_ARG_NONE, NULL, 'C', "recompute CHS values in protective/hybrid MBR", ""},
       {"delete", 'd', POPT_ARG_INT, &deletePartNum, 'd', "delete a partition", "partnum"},
       {"display-alignment", 'D', POPT_ARG_NONE, NULL, 'D', "show number of sectors per allocation block", ""},
-      {"move-second-header", 'e', POPT_ARG_NONE, NULL, 'e', "move second header to end of disk", ""},
+      {"move-second-header", 'e', POPT_ARG_NONE, NULL, 'e', "move second/backup header to end of disk", ""},
       {"end-of-largest", 'E', POPT_ARG_NONE, NULL, 'E', "show end of largest free block", ""},
       {"first-in-largest", 'f', POPT_ARG_NONE, NULL, 'f', "show start of the largest free block", ""},
       {"first-aligned-in-largest", 'F', POPT_ARG_NONE, NULL, 'F', "show start of the largest free block, aligned", ""},
       {"mbrtogpt", 'g', POPT_ARG_NONE, NULL, 'g', "convert MBR to GPT", ""},
       {"randomize-guids", 'G', POPT_ARG_NONE, NULL, 'G', "randomize disk and partition GUIDs", ""},
-      {"hybrid", 'h', POPT_ARG_STRING, &hybrids, 'h', "create hybrid MBR", "partnum[:partnum...]"},
+      {"hybrid", 'h', POPT_ARG_STRING, &hybrids, 'h', "create hybrid MBR", "partnum[:partnum...][:EE]"},
       {"info", 'i', POPT_ARG_INT, &infoPartNum, 'i', "show detailed information on partition", "partnum"},
-      {"move-main-table", 'j', POPT_ARG_INT, &mainTableLBA, 'j', "adjust the location of the main partition table", "sector"},
+      {"align-end", 'I', POPT_ARG_NONE, NULL, 'I', "align partition end points", ""},
+      {"move-main-table", 'j', POPT_ARG_INT, &mainTableLBA, 'j', "change the start sector of the main partition table", "sector"},
+      {"move-backup-table", 'k', POPT_ARG_INT, &secondTableLBA, 'k', "change the start sector of the second/backup partition table", "sector"},
       {"load-backup", 'l', POPT_ARG_STRING, &backupFile, 'l', "load GPT backup from file", "file"},
       {"list-types", 'L', POPT_ARG_NONE, NULL, 'L', "list known partition types", ""},
       {"gpttombr", 'm', POPT_ARG_STRING, &mbrParts, 'm', "convert GPT to MBR", "partnum[:partnum...]"},
@@ -111,6 +118,7 @@ int GPTDataCL::DoOptions(int argc, char* argv[]) {
       {"zap", 'z', POPT_ARG_NONE, NULL, 'z', "zap (destroy) GPT (but not MBR) data structures", ""},
       {"zap-all", 'Z', POPT_ARG_NONE, NULL, 'Z', "zap (destroy) GPT and MBR data structures", ""},
       POPT_AUTOHELP { NULL, 0, 0, NULL, 0 }
+      // TODO: Incorrect(ly documented) (long) arguments are silently swallowed and seem to take the next argument with them!
    };
 
    // Create popt context...
@@ -150,9 +158,10 @@ int GPTDataCL::DoOptions(int argc, char* argv[]) {
 
    // Assume first non-option argument is the device filename....
    device = (char*) poptGetArg(poptCon);
-   poptResetContext(poptCon);
 
    if (device != NULL) {
+      device = strdup(device);
+      poptResetContext(poptCon);
       JustLooking(); // reset as necessary
       BeQuiet(); // Tell called functions to be less verbose & interactive
       if (LoadPartitions((string) device)) {
@@ -191,17 +200,24 @@ int GPTDataCL::DoOptions(int argc, char* argv[]) {
                case 'a':
                   SetAlignment(alignment);
                   break;
+               case 'B':
+                  if (IsUsedPartNum(byteSwapPartNum - 1)) {
+                     partitions[byteSwapPartNum - 1].ReverseNameBytes();
+                     cout << "Changed partition " << byteSwapPartNum << "'s name to "
+                          << partitions[byteSwapPartNum - 1].GetDescription() << "\n";
+                     JustLooking(0);
+                     saveData = 1;
+                  }
+                  break;
                case 'b':
                   SaveGPTBackup(backupFile);
                   free(backupFile);
                   break;
                case 'c':
-                  cout << "Setting name!\n";
                   JustLooking(0);
                   partNum = (int) GetInt(partName, 1) - 1;
                   if (partNum < 0)
                      partNum = newPartNum;
-                  cout << "partNum is " << partNum << "\n";
                   if ((partNum >= 0) && (partNum < (int) GetNumParts())) {
                      name = GetString(partName, 2);
                      if (SetName(partNum, (UnicodeString) name.c_str())) {
@@ -263,14 +279,25 @@ int GPTDataCL::DoOptions(int argc, char* argv[]) {
                case 'i':
                   ShowPartDetails(infoPartNum - 1);
                   break;
+               case 'I':
+                  alignEnd = true;
+                  break;
                case 'j':
-                   if (MoveMainTable(mainTableLBA)) {
-                       JustLooking(0);
-                       saveData = 1;
-                   } else {
-                       neverSaveData = 1;
-                   } // if/else
-                   break;
+                  if (MoveMainTable(mainTableLBA)) {
+                     JustLooking(0);
+                     saveData = 1;
+                  } else {
+                     neverSaveData = 1;
+                  } // if/else
+                  break;
+               case 'k':
+                  if (MoveSecondTable(secondTableLBA)) {
+                     JustLooking(0);
+                     saveData = 1;
+                  } else {
+                     neverSaveData = 1;
+                  } // if/else
+                  break;
                case 'l':
                   LoadBackupFile(backupFile, saveData, neverSaveData);
                   free(backupFile);
@@ -298,9 +325,9 @@ int GPTDataCL::DoOptions(int argc, char* argv[]) {
                      newPartNum = FindFirstFreePart();
                   low = FindFirstInLargest();
                   Align(&low);
-                  high = FindLastInFree(low);
-                  startSector = IeeeToInt(GetString(newPartInfo, 2), sSize, low, high, low);
-                  endSector = IeeeToInt(GetString(newPartInfo, 3), sSize, startSector, high, high);
+                  high = FindLastInFree(low, alignEnd);
+                  startSector = IeeeToInt(GetString(newPartInfo, 2), sSize, low, high, sectorAlignment, low);
+                  endSector = IeeeToInt(GetString(newPartInfo, 3), sSize, startSector, high, sectorAlignment, high);
                   if (CreatePartition(newPartNum, startSector, endSector)) {
                      saveData = 1;
                   } else {
@@ -314,9 +341,11 @@ int GPTDataCL::DoOptions(int argc, char* argv[]) {
                   JustLooking(0);
                   startSector = FindFirstInLargest();
                   Align(&startSector);
-                  endSector = FindLastInFree(startSector);
-                  if (largestPartNum <= 0)
+                  endSector = FindLastInFree(startSector, alignEnd);
+                  if (largestPartNum <= 0) {
                      largestPartNum = FindFirstFreePart() + 1;
+                     newPartNum = largestPartNum - 1;
+                  }
                   if (CreatePartition(largestPartNum - 1, startSector, endSector)) {
                      saveData = 1;
                   } else {
@@ -375,7 +404,7 @@ int GPTDataCL::DoOptions(int argc, char* argv[]) {
                      partNum = newPartNum;
                   if ((partNum >= 0) && (partNum < (int) GetNumParts())) {
                      typeHelper = GetString(typeCode, 2);
-                     if ((typeHelper != (GUIDData) "00000000-0000-0000-0000-000000000000") &&
+                     if ((typeHelper != PartType::unusedPartType) &&
                          (ChangePartType(partNum, typeHelper))) {
                         saveData = 1;
                         } else {
@@ -482,6 +511,7 @@ int GPTDataCL::DoOptions(int argc, char* argv[]) {
          cerr << "Error encountered; not saving changes.\n";
          retval = 4;
       } // if
+      free(device);
    } // if (device != NULL)
    poptFreeContext(poptCon);
    return retval;
@@ -490,33 +520,47 @@ int GPTDataCL::DoOptions(int argc, char* argv[]) {
 // Create a hybrid or regular MBR from GPT data structures
 int GPTDataCL::BuildMBR(char* argument, int isHybrid) {
    int numParts, allOK = 1, i, origPartNum;
+   int eeLast = 0, mbrNum = 0;
    MBRPart newPart;
    BasicMBRData newMBR;
 
    if (argument != NULL) {
       numParts = CountColons(argument) + 1;
+      if (isHybrid) {
+         eeLast = GetString(argument, numParts) == "EE";
+         if (eeLast) {
+            numParts--;
+         }
+      }
+
       if (numParts <= (4 - isHybrid)) {
          newMBR.SetDisk(GetDisk());
          for (i = 0; i < numParts; i++) {
             origPartNum = GetInt(argument, i + 1) - 1;
             if (IsUsedPartNum(origPartNum) && (partitions[origPartNum].IsSizedForMBR() == MBR_SIZED_GOOD)) {
+               mbrNum = i + (isHybrid && ! eeLast);
                newPart.SetInclusion(PRIMARY);
                newPart.SetLocation(operator[](origPartNum).GetFirstLBA(),
                                    operator[](origPartNum).GetLengthLBA());
                newPart.SetStatus(0);
                newPart.SetType((uint8_t)(operator[](origPartNum).GetHexType() / 0x0100));
-               newMBR.AddPart(i + isHybrid, newPart);
+               newMBR.AddPart(mbrNum, newPart);
             } else {
                cerr << "Original partition " << origPartNum + 1 << " does not exist or is too big! Aborting operation!\n";
                allOK = 0;
             } // if/else
          } // for
          if (isHybrid) {
+            if (eeLast) {
+               mbrNum = i;
+            } else {
+               mbrNum = 0;
+            }
             newPart.SetInclusion(PRIMARY);
             newPart.SetLocation(1, newMBR.FindLastInFree(1));
             newPart.SetStatus(0);
             newPart.SetType(0xEE);
-            newMBR.AddPart(0, newPart);
+            newMBR.AddPart(mbrNum, newPart);
          } // if
          if (allOK)
             SetProtectiveMBR(newMBR);
